( cd opt/kde/share/doc/HTML/en_GB/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdm ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kate ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdesu ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kfind ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/klipper ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/konsole ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kioslave ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kpager ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kspell ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kwrite ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
